##  Explore Use Cases
SAP LeanIX offers various use cases to help enterprise architects shape the digital landscape of their organization. Explore use cases and develop your strategy. Start with application portfolio assessment, then proceed to more advanced use cases.
SAP LeanIX Application Portfolio Management | SAP LeanIX Technology Risk and Compliance | SAP LeanIX Architecture and Road Map Planning
---|---|---
[Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.") | [Obsolescence Risk Management](https://help.sap.com/docs/leanix/ea/obsolescence-risk-management?locale=en-US&state=PRODUCTION&version=CLOUD "Learn why obsolescence risk management matters, how to discover risks associated with obsolete technology, how to assess their business impact, and how to efficiently manage and address them with SAP LeanIX.") | [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.")
[Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") |  | [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.")
[AI Governance and Adoption](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to implement AI governance practices in SAP LeanIX.") |  |


